@@ -47,8 +47,12 @@ class BingHasChangedException(Exception):
     pass
 
 
+class IdpPageOpenedOnClick(Exception):
+    def __init__(self, opened_url, starting_point_next_try):
+        self.opened_url = opened_url
+        self.starting_point_next_try = starting_point_next_try
+
+
 class WebDriverInitialisationException(Exception):
     def __init__(self, e):
         self.thrown_exception = e
-
-    pass
