@@ -1,5 +1,7 @@
 import time
 
+from selenium.common.exceptions import TimeoutException
+
 from logmgmt import logger
 from exceptions import RenewalRequestNeededException
 from input.input_management import InputManager
@@ -47,8 +49,13 @@ class SSODetectionService:
                                   "Identifying Google SSO Support for " + latest_login_info.loginPath)
             logger.info("--- Google ---")
             start_time = time.time()
-            google_locate_result = self.locators['google'].locate_login(chromedriver, latest_login_info, special_check)
-            logger.info("--- Finished Google in " + str(round(time.time() - start_time, 2)) + "s ---")
+            try:
+                google_locate_result = self.locators['google'].locate_login(chromedriver, latest_login_info,
+                                                                            special_check)
+                logger.info("--- Finished Google in " + str(round(time.time() - start_time, 2)) + "s ---")
+            except TimeoutException:
+                google_locate_result = False,
+                logger.info("--- Analysis for Google failed after " + str(round(time.time() - start_time, 2)) + "s ---")
             if google_locate_result[0]:
                 ids.append((self.provider_ids['google'], google_locate_result[1], google_locate_result[2],
                             latest_login_info.loginPath, google_locate_result[3]))
@@ -60,9 +67,15 @@ class SSODetectionService:
                                   "Identifying Facebook SSO Support for " + latest_login_info.loginPath)
             logger.info("--- Facebook ---")
             start_time = time.time()
-            facebook_locate_result = self.locators['facebook'].locate_login(chromedriver, latest_login_info,
-                                                                            special_check)
-            logger.info("--- Finished Facebook in " + str(round(time.time() - start_time, 2)) + "s ---")
+            try:
+                facebook_locate_result = self.locators['facebook'].locate_login(chromedriver, latest_login_info,
+                                                                                special_check)
+                logger.info("--- Finished Facebook in " + str(round(time.time() - start_time, 2)) + "s ---")
+            except TimeoutException:
+                facebook_locate_result = False,
+                logger.info(
+                    "--- Analysis for Facebook failed after " + str(round(time.time() - start_time, 2)) + "s ---")
+
             if facebook_locate_result[0]:
                 ids.append((self.provider_ids['facebook'], facebook_locate_result[1], facebook_locate_result[2],
                             latest_login_info.loginPath, facebook_locate_result[3]))
@@ -74,8 +87,13 @@ class SSODetectionService:
                                   "Identifying Apple SSO Support for " + latest_login_info.loginPath)
             logger.info("--- Apple ---")
             start_time = time.time()
-            apple_locate_result = self.locators['apple'].locate_login(chromedriver, latest_login_info, special_check)
-            logger.info("--- Finished Apple in " + str(round(time.time() - start_time, 2)) + "s ---")
+            try:
+                apple_locate_result = self.locators['apple'].locate_login(chromedriver, latest_login_info,
+                                                                          special_check)
+                logger.info("--- Finished Apple in " + str(round(time.time() - start_time, 2)) + "s ---")
+            except TimeoutException:
+                apple_locate_result = False,
+                logger.info("--- Analysis for Apple failed after " + str(round(time.time() - start_time, 2)) + "s ---")
             if apple_locate_result[0]:
                 ids.append((self.provider_ids['apple'], apple_locate_result[1], apple_locate_result[2],
                             latest_login_info.loginPath, apple_locate_result[3]))
