@@ -247,32 +247,32 @@ def process_function(sso_detection, backend_info: BackendInformation, analysis_r
         chromedriver.execute_cdp_cmd('Network.enable', {})
 
         logger.info("Checking login state")
-        rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 10,
+        rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 5,
                                                                     "Checking profile")
         if not ProcessHelper().check_log_in_state(chromedriver):
             raise ConfigInvalidException()
         logger.info("Opening finding page")
-        rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 25,
+        rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 10,
                                                                     "Opening finding page " + finding_url)
         chromedriver.get(finding_url)
         if chromedriver.get_window_size()['width'] < element_x or chromedriver.get_window_size()['height'] < element_y:
             offset = scroll_to_position(chromedriver, element_x, element_y)
             element_x -= offset[0]
             element_y -= offset[1]
-        rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 35,
+        rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 15,
                                                                     "Taking screenshot of " + finding_url)
         logger.info("Taking screenshot")
         sleep(10)
         screen = chromedriver.get_screenshot_as_png()
-        screen = png_helper.draw_circle_at_position(screen, element_x, element_y)
-        rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 40,
+        screen = png_helper.draw_circle_at_position(screen, element_x, element_y, color="green")
+        rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 20,
                                                                     "Pressing element coordinates")
         logger.info("Pressing coordinates")
         action = ActionChains(chromedriver)
         try:
             action.move_by_offset(element_x, element_y).click().move_by_offset(element_x * -1, element_y * -1).perform()
             logger.info("Waiting for login finished")
-            rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 50,
+            rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 25,
                                                                         "Waiting for finished login after pressing element coordinates")
             sleep(1)
             result = wait_for_result(chromedriver, social_login_info)
@@ -288,28 +288,58 @@ def process_function(sso_detection, backend_info: BackendInformation, analysis_r
         error_screen = chromedriver.get_screenshot_as_png()
         if element_width is not None and element_height is not None:
             logger.info("Pressing at coordinates did not get a valid result. Trying to press in center of element")
-            rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 55,
+            rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 30,
                                                                         "Pressing element's center")
             chromedriver.get(finding_url)
             sleep(10)
             newx = element_x + element_width / 2
             newy = element_y + element_height / 2
-            screen = png_helper.draw_circle_at_position(screen, newx, newy, color="orange")
+            screen = png_helper.draw_circle_at_position(screen, newx, newy, color="yellow")
             action.move_by_offset(newx, newy).click().move_by_offset(newx * -1, newy * -1).perform()
             logger.info("Waiting for login finished")
-            rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 50,
+            rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 35,
                                                                         "Waiting for finished login after pressing element's center")
             result = wait_for_result(chromedriver, social_login_info)
             if result[0]:
                 success = handle_result_found(result, rest_client, analysis_run_id, sso_detection_index, screen,
                                               chromedriver.har)
                 return
+        if sso_detection_strategy == SSODetectionStrategy.IMAGE_ANALYSIS or sso_detection_strategy == SSODetectionStrategy.ELEMENT_SEARCH:
+            logger.info("Nothing found! Falling back to pressing around the coordinates")
+            rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 40,
+                                                                        "Fallback pressing around the elements location")
+            result = False,
+            trips = 0
+            colors = ["orange", "brown", "red", "purple"]
+            while trips < 4:
+                if trips == 0:
+                    element_y += 20
+                if trips == 1 or trips == 3:
+                    element_x += 10
+                if trips == 2:
+                    element_y += 10
+                screen = png_helper.draw_circle_at_position(screen, element_x, element_y, color=colors[trips])
+                trips += 1
+                action.move_by_offset(element_x, element_y).click().move_by_offset(element_x * -1,
+                                                                                   element_y * -1).perform()
+                logger.info(
+                    "Waiting for login finished at positions down and right to original coordinates (round " + str(
+                        trips) + ")")
+                rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index,
+                                                                            40 + (trips * 5),
+                                                                            "Waiting for finished login after pressing around the elements location (" + str(
+                                                                                trips) + "/4)")
+                result = wait_for_result(chromedriver, social_login_info)
+                if result[0]:
+                    success = handle_result_found(result, rest_client, analysis_run_id, sso_detection_index, screen,
+                                                  chromedriver.har)
+                    return
         if sso_detection_strategy == SSODetectionStrategy.ELEMENT_SEARCH:
             from processes import SSODetectionService
             from model.login_path_information import LoginPathInformation
             from model.page_information import PageInformation
             logger.info("Nothing found! Falling back to identify login element")
-            rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 60,
+            rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 65,
                                                                         "Preparing fallback identification for sso element")
             chromedriver.get(finding_url)
             service = SSODetectionService(rest_client.get_known_sso_provider())
@@ -318,7 +348,7 @@ def process_function(sso_detection, backend_info: BackendInformation, analysis_r
 
             def progress_callback(step: int, max: int, status: str):
                 rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index,
-                                                                            int(60 + (20 * (step / max))), status)
+                                                                            int(65 + (20 * (step / max))), status)
 
             def special_check(d):
                 return wait_for_result(d, social_login_info, 15)[0]
@@ -332,14 +362,7 @@ def process_function(sso_detection, backend_info: BackendInformation, analysis_r
             rawres = service.automatic_sso_detection(chromedriver, mock_latest_login_info, progress_callback,
                                                      run_google, run_facebook, run_apple, special_check)[0]
             result = wait_for_result(chromedriver, social_login_info)
-            if result[0] is False:
-                logger.warning("Fallback also did not find valid login button. Saving as error")
-                rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 90,
-                                                                            "Uploading failed analysis data")
-                rest_client.save_sso_security_analysis(analysis_run_id, sso_detection_index, (result[1], result[2]),
-                                                       screen, chromedriver.har, False, "Did not find auth req and res",
-                                                       error_screenshot=error_screen)
-            else:
+            if result[0] is True:
                 logger.info("Fallback located element successfully, saving results")
                 rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 90,
                                                                             "Uploading results")
@@ -349,6 +372,13 @@ def process_function(sso_detection, backend_info: BackendInformation, analysis_r
                 logger.info(result)
                 rest_client.save_sso_security_analysis(analysis_run_id, sso_detection_index, (result[1], result[2]),
                                                        screen, chromedriver.har)
+                return
+        logger.warning("Fallback also did not find valid login button. Saving as error")
+        rest_client.update_progress_of_analysis_using_sso_detection(analysis_run_id, sso_detection_index, 90,
+                                                                    "Uploading failed analysis data")
+        rest_client.save_sso_security_analysis(analysis_run_id, sso_detection_index, (result[1], result[2]),
+                                               screen, chromedriver.har, False, "Did not find auth req and res",
+                                               error_screenshot=error_screen)
 
 
     except TimeoutException as err:
